from setuptools import setup

setup(name='ftThanos',
version="0.0.65",
description="A client for 65 API",
author="Thanos 65",
author_email="thanos@65paris.fr",
packages=["ftThanos"],
install_requires=["requests","python-dotenv"],
)
